==> MediaWikiLanguageExtensionBundle-2020.07.tar.bz2: extensions/cldr/LocalNames/LocalNamesFa.php <==
<?php

$languageNames = [

	/* Not in CLDR 27.0.1. Name Gheg Albanian used by Ethnologue:
	 * https://www.ethnologue.com/language/aln
	 * Added 2008-01-04.
	 */
	// 'aln' => 'Gheg Albanian',

	/* Not in CLDR 27.0.1. Southern Balochi language
	 * https://www.ethnologue.com/language/bcc
	 * Added 2008-07-02.
	 */
	'bcc' => 'بلوچی جنوبی',

	/* Not in CLDR 27.0.1. Western Balochi language
	 * https://www.ethnologue.com/language/bgn
	 * Added 2015-01-18.
	 */
	'bgn' => 'بلوچی غربی',

	/* Not in CLDR 27.0.1. Eastern Balochi language
	 * https://www.ethnologue.com/language/bgp
	 */
	'bgp' => 'بلوچی شرقی',

	/* Not in CLDR 27.0.1. Betawi language.
	 * https://www.ethnologue.com/language/bew
	 * Added 2011-11-10.
	 */
	// 'bew' => 'Betawi',

	/* Not in CLDR 27.0.1. Malay language.
	 * https://www.ethnologue.com/language/bjn
	 * Added 2011-09-10.
	 */
	'bjn' => 'بانجاری',

	/* Not in CLDR 27.0.1. Name Bishnupriya used by Ethnologue:
	 * https://www.ethnologue.com/language/bpy
	 * Added 2007-11-10.
	 */
	// 'bpy' => 'Bishnupriya Manipuri',

	/* Not in CLDR 27.0.1. Western Cham language
	* https://www.ethnologue.com/language/cja
	*/
	'cja' => 'چِم غربی',
	'cja-cham' => 'چِم غربی (خط چِم)',
	'cja-latn' => 'چِم غربی (خط لاتین)',
	'cja-arab' => 'چِم غربی (خط عربی)',

	/* Not in CLDR 27.0.1. Eastern Cham language
	* https://www.ethnologue.com/language/cjm
	*/
	'cjm' => 'چِم شرقی',
	'cjm-cham' => 'چِم شرقی (خط چِم)',
	'cjm-latn' => 'چِم شرقی (خط لاتین)',
	'cjm-arab' => 'چِم شرقی (خط عربی)',

	/* Not in CLDR 27.0.1. Jinyu language
	 * https://www.ethnologue.com/language/cjy
	 */
	'cjy' => 'جینیو',
	'cjy-hans' => 'جینیو (ساده‌شده)',
	'cjy-hant' => 'جینیو (سنتی)',

	/* Not in CLDR 27.0.1. Bisayan language
	 * https://www.ethnologue.com/language/cps
	 * Added 2010-01-11.
	 */
	// 'cps' => 'Capiznon',

	/* Not in CLDR 27.0.1. Swedish language
	 * https://www.ethnologue.com/language/dlc
	 * Added 2008-02-16.
	 */
	// 'dlc' => 'Dalecarlian',

	/* Not in CLDR 27.0.1. Central Dusun language
	 * https://www.ethnologue.com/language/dtp
	 * Added 2011-04-16.
	 */
	// 'dtp' => 'Central Dusun',

	/* Not in CLDR 21.0.1. Romance language.
	 * https://www.ethnologue.com/language/eml
	 * Added 2008-01-17.
	 */
	'eml' => 'امیلیانو-روما',

	/* Not in CLDR 27.0.1. Romance language.
	 * https://www.ethnologue.com/language/ext
	 * Added 2007-12-02.
	 */
	'ext' => 'اکسترامادورایی',

	/* Not in CLDR 27.0.1. Romance language.
	 * https://www.ethnologue.com/language/frp
	 * Added 2007-12-02.
	 */
	'frp' => 'آرپیتان',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/hak
	 * Added 2007-12-02.
	 */
	// 'hak' => 'Hakka',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/gan
	 * Added 2007-12-02.
	 */
	'gan' => 'گن',

	/* Not in CLDR 27.0.1. Konkani language
	 * https://www.ethnologue.com/language/gom
	 * Added 2008-09-02.
	 */
	'gom' => 'کونکانی گن',
	'gom-deva' => 'کونکانی گن (خط دیواناگری)',
	'gom-latn' => 'کونکانی گن (خط لاتین)',

	/* Not in CLDR 27.0.1. Western Atlantic Creole language
	 * https://www.ethnologue.com/language/dtp
	 * Added 2011-04-16.
	 */
	// 'jam' => 'Jamaican Creole English',

	/* Not in CLDR 27.0.1. Danish language.
	 * https://www.ethnologue.com/language/jut
	 * Added 2008-02-06.
	 */
	// 'jut' => 'Jutish',

	/* Not in CLDR 27.0.1. Maharashtrian Konkani language
	 * https://www.ethnologue.com/language/knn
	 */
	'knn' => 'کونکانی مراتی',

	/* Not in CLDR 27.0.1. Artificial language.
	 * https://www.ethnologue.com/language/lfn
	 * Added 2008-01-18.
	 */
	// 'lfn' => 'Lingua Franca Nova',

	/* Not in CLDR 27.0.1. Laki language
	 * https://www.ethnologue.com/language/lki
	 */
	'lki' => 'لکی',

	/* Not in CLDR 27.0.1. Latvian language
	 * https://iso639-3.sil.org/code/ltg
	 * Added 2010-04-03.
	 */
	'ltg' => 'لاتگالی',

	/* Not in CLDR 27.0.1. Northern Luri language
	 * https://www.ethnologue.com/language/lrc
	 */
	'lrc' => 'لری شمالی',

	/* Not in CLDR 27.0.1. Southern Luri language
	 * https://www.ethnologue.com/language/luz
	 */
	'luz' => 'لری جنوبی',

	/* Not in CLDR 27.0.1. Mari language
	 * https://www.ethnologue.com/language/mhr
	 * Added 2008-05-22.
	 */
	'mhr' => 'ماری',

	/* Not in CLDR 27.0.1. Mari language
	 * https://www.ethnologue.com/language/mrj
	 * Added 2009-11-22.
	 */
	'mrj' => 'هیل ماری',

	/* Not in CLDR 27.0.1. Malay language
	 * https://www.ethnologue.com/language/mui
	 * Added 2010-02-11.
	 */
	// 'mui' => 'Musi',

	/* Not in CLDR 27.0.1. Caspian language
	 * https://www.ethnologue.com/language/mzn
	 * Added 2008-03-01.
	 */
	'mzn' => 'مازندرانی',

	/* Not in CLDR 27.0.1. Chinese language
	 * https://www.ethnologue.com/language/nan
	 * Added 2008-03-01.
	 */
	'nan' => 'مین نان',

	/* Not in CLDR 27.0.1. Tibeto-Burman family language.
	 * https://www.ethnologue.com/language/njo
	 * Added 2008-01-14.
	 */
	// 'njo' => 'Ao Naga',

	/* Not in CLDR 27.0.1. Livvi-Karelian language
	 * https://www.ethnologue.com/language/olo
	 */
	'olo' => 'لیوی-کارلیان',

	/* Not in CLDR 27.0.1. Gallo-Italian language.
	 * https://www.ethnologue.com/language/pms
	 * Added 2008-07-09.
	 */
	'pms' => 'پیدمونتی',

	/* Not in CLDR 27.0.1. Lahnda language.
	 * https://www.ethnologue.com/language/pnb
	 * Added 2008-10-29.
	 */
	'pnb' => 'پنجابی',

	/* Not in CLDR 27.0.1. Attic language.
	 * https://www.ethnologue.com/language/pnt
	 * Added 2008-01-18.
	 */
	// 'pnt' => 'Pontic',

	/* Not in CLDR 27.0.1. Dari language.
	 * https://www.ethnologue.com/language/prs
	 */
	'prs' => 'دری',

	/* Not in CLDR 27.0.1. Gallo-Italic language.
	 * https://iso639-3.sil.org/code/rgn
	 * Added 2009-11-15.
	 */
	'rgn' => 'رومانیولو',

	/* Not in CLDR 27.0.1. East Slavic language.
	 * https://www.ethnologue.com/language/rue
	 * Added 2010-04-03.
	 */
	// 'rue' => 'Rusyn',

	/* Not in CLDR 27.0.1. Eastern Romance language.
	 * https://www.ethnologue.com/language/ruq
	 * Added 2008-02-04.
	 */
	'ruq' => 'مگلنو رومانی',
	'ruq-cyrl' => 'مگلنو رومانی (خط سرلیک)',
	'ruq-grek' => 'مگلنو رومانی (خط یونانی)',
	'ruq-latn' => 'مگلنو رومانی (خط لاتین)',

	/* Not in CLDR 27.0.1.
	 * https://iso639-3.sil.org/code/sgs
	 * Added 2010-10-14.
	 */
	'sgs' => 'ساموگیتی',

	/* Not in CLDR 27.0.1. Shawiya language
	 * https://www.ethnologue.com/language/shy
	 */
	'shy' => 'شاویایی',
	'shy-arab' => 'شاویایی (خط عربی)',
	'shy-latn' => 'شاویایی (خط لاتین)',
	'shy-tfng' => 'شاویایی (خط تیفیناغی)',

	/* Not in CLDR 27.0.1.
	 * https://iso639-3.sil.org/code/sli
	 * Added 2008-09-02.
	 */
	'sli' => 'سیلزیایی پایین',

	/* Not in CLDR 27.0.1.
	 * https://iso639-3.sil.org/code/szl
	 * Added 2008-03-29.
	 */
	'szl' => 'سیلزیایی',

	/* Not in CLDR 27.0.1. Tulu language
	 * https://iso639-3.sil.org/code/tcy
	 * Added 2008-08-23.
	 */
	'tcy' => 'تولو',

	/* Not in CLDR 27.0.1. Turoyo language
	 * https://iso639-3.sil.org/code/tru
	 * Added 2012-07-26.
	 */
	// 'tru' => 'Turoyo',

	/* Not in CLDR 27.0.1. Finnic Uralic language.
	 * https://www.ethnologue.com/language/vep
	 * Added 2009-01-24.
	 */
	'vep' => 'وپس',

	/* Not in CLDR 27.0.1. West Middle German language.
	 * https://iso639-3.sil.org/code/vmf
	 * Added 2010-01-31.
	 */
	// 'vmf' => 'Upper Franconian',

	/* Not in CLDR 27.0.1. Estonian language.
	 * https://iso639-3.sil.org/code/vro
	 * Added 2009-01-24.
	 */
	// 'vro' => 'Võro',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/wuu
	 * Added 2007-12-02.
	 */
	'wuu' => 'وو',

	/* Not in CLDR 27.0.1. Low Franconian language.
	 * https://www.ethnologue.com/language/zea
	 * Added 2008-01-17.
	 */
	'zea' => 'زیلاندی',

	/* Not in CLDR 27.0.1. Used for MediaWiki localisation
	 */
	'bat-smg' => 'ساموگیتی',
	'be-tarask' => 'بلاروسی (دستورخط کلاسیک)',
	'cdo' => 'چینی مین شرقی',
	'crh-cyrl' => 'ترکی کریمه (خط سرلیک)',
	'crh-latn' => 'ترکی کریمه (خط لاتین)',
	// 'de-formal' => 'German (formal address)',
	'gan-hans' => 'خط گن ساده‌شده',
	'gan-hant' => 'خط گن سنتی',
	'hif-latn' => 'هندی فیجی (خط لاتینی)',
	'ike-cans' => 'کانادایی شرقی (هجاهای بومی)',
	'ike-latn' => 'کانادایی شرقی (خط لاتینی)',
	'kk-cn' => 'قزافی(چینی)',
	'kk-kz' => 'قزاقی (قزاقستان)',
	'kk-tr' => 'قزاقی (ترکیە)',
	'kk-arab' => 'قزاقی (خط عربی)',
	'kk-cyrl' => 'قزاقی (خط سریلیک)',
	'kk-latn' => 'قزاقی (خط لاتینی)',
	'ks-arab' => 'کشمیری (خط عربی)',
	'ks-deva' => 'کشمیری (خط دیواناگری)',
	'ku-latn' => 'کردی (خط لاتین)',
	// 'nds-nl' => 'Low Saxon (Netherlands)',
	'roa-rup' => 'آرومانی',
	'sr-ec' => 'صربی (خط سرلیک)',
	'sr-el' => 'صربی (خط لاتین)',
	'tg-cyrl' => 'تاجیکی (خط سرلیک)',
	'tg-latn' => 'تاجیکی (خط لاتین)',
	'tt-cyrl' => 'تاتاری (خط سرلیک)',
	'tt-latn' => 'تاتاری (خط لاتین)',
	'ug-arab' => 'اویغوری (خط عربی)',
	'ug-latn' => 'اویغوری (خط لاتین)',
	// 'xmf' => 'Mingrelian',
	'ydd' => 'ییدیشی شرقی',
	'zh-classical' => 'چینی کلاسیک',
	'zh-cn' => 'چینی (چین)',
	'zh-hk' => 'چینی (هنگ کنگ)',
	'zh-min-nan' => 'چینی (مین نان)',
	'zh-sg' => 'چینی (سنگاپور)',
	'zh-tw' => 'چینی (تایوان)',
	'zh-yue' => 'کانتونی', # language redirect

	/* additional list from Persian Wikipedia */
	'simple' => 'انگلیسی ساده',
];

==> MediaWikiLanguageExtensionBundle-2021.06.tar.bz2: extensions/cldr/LocalNames/LocalNamesFa.php <==
<?php

$languageNames = [

	/* Not in CLDR 27.0.1. Name Gheg Albanian used by Ethnologue:
	 * https://www.ethnologue.com/language/aln
	 * Added 2008-01-04.
	 */
	// 'aln' => 'Gheg Albanian',

	/* Not in CLDR 27.0.1. Southern Balochi language
	 * https://www.ethnologue.com/language/bcc
	 * Added 2008-07-02.
	 */
	'bcc' => 'بلوچی جنوبی',

	/* Not in CLDR 27.0.1. Eastern Balochi language
	 * https://www.ethnologue.com/language/bgp
	 */
	'bgp' => 'بلوچی شرقی',

	/* Not in CLDR 27.0.1. Betawi language.
	 * https://www.ethnologue.com/language/bew
	 * Added 2011-11-10.
	 */
	// 'bew' => 'Betawi',

	/* Not in CLDR 27.0.1. Malay language.
	 * https://www.ethnologue.com/language/bjn
	 * Added 2011-09-10.
	 */
	'bjn' => 'بانجاری',

	/* Not in CLDR 27.0.1. Name Bishnupriya used by Ethnologue:
	 * https://www.ethnologue.com/language/bpy
	 * Added 2007-11-10.
	 */
	// 'bpy' => 'Bishnupriya Manipuri',

	/* Not in CLDR 27.0.1. Western Cham language
	* https://www.ethnologue.com/language/cja
	*/
	'cja' => 'چِم غربی',
	'cja-cham' => 'چِم غربی (خط چِم)',
	'cja-latn' => 'چِم غربی (خط لاتین)',
	'cja-arab' => 'چِم غربی (خط عربی)',

	/* Not in CLDR 27.0.1. Eastern Cham language
	* https://www.ethnologue.com/language/cjm
	*/
	'cjm' => 'چِم شرقی',
	'cjm-cham' => 'چِم شرقی (خط چِم)',
	'cjm-latn' => 'چِم شرقی (خط لاتین)',
	'cjm-arab' => 'چِم شرقی (خط عربی)',

	/* Not in CLDR 27.0.1. Jinyu language
	 * https://www.ethnologue.com/language/cjy
	 */
	'cjy' => 'جینیو',
	'cjy-hans' => 'جینیو (ساده‌شده)',
	'cjy-hant' => 'جینیو (سنتی)',

	/* Not in CLDR 27.0.1. Bisayan language
	 * https://www.ethnologue.com/language/cps
	 * Added 2010-01-11.
	 */
	// 'cps' => 'Capiznon',

	/* Not in CLDR 27.0.1. Swedish language
	 * https://www.ethnologue.com/language/dlc
	 * Added 2008-02-16.
	 */
	// 'dlc' => 'Dalecarlian',

	/* Not in CLDR 27.0.1. Central Dusun language
	 * https://www.ethnologue.com/language/dtp
	 * Added 2011-04-16.
	 */
	// 'dtp' => 'Central Dusun',

	/* Not in CLDR 21.0.1. Romance language.
	 * https://www.ethnologue.com/language/eml
	 * Added 2008-01-17.
	 */
	'eml' => 'امیلیانو-روما',

	/* Not in CLDR 27.0.1. Romance language.
	 * https://www.ethnologue.com/language/ext
	 * Added 2007-12-02.
	 */
	'ext' => 'اکسترامادورایی',

	/* Not in CLDR 27.0.1. Romance language.
	 * https://www.ethnologue.com/language/frp
	 * Added 2007-12-02.
	 */
	'frp' => 'آرپیتان',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/hak
	 * Added 2007-12-02.
	 */
	// 'hak' => 'Hakka',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/gan
	 * Added 2007-12-02.
	 */
	'gan' => 'گن',

	/* Not in CLDR 27.0.1. Konkani language
	 * https://www.ethnologue.com/language/gom
	 * Added 2008-09-02.
	 */
	'gom' => 'کونکانی گن',
	'gom-deva' => 'کونکانی گن (خط دیواناگری)',
	'gom-latn' => 'کونکانی گن (خط لاتین)',

	/* Not in CLDR 27.0.1. Western Atlantic Creole language
	 * https://www.ethnologue.com/language/dtp
	 * Added 2011-04-16.
	 */
	// 'jam' => 'Jamaican Creole English',

	/* Not in CLDR 27.0.1. Danish language.
	 * https://www.ethnologue.com/language/jut
	 * Added 2008-02-06.
	 */
	// 'jut' => 'Jutish',

	/* Not in CLDR 27.0.1. Maharashtrian Konkani language
	 * https://www.ethnologue.com/language/knn
	 */
	'knn' => 'کونکانی مراتی',

	/* Not in CLDR 27.0.1. Artificial language.
	 * https://www.ethnologue.com/language/lfn
	 * Added 2008-01-18.
	 */
	// 'lfn' => 'Lingua Franca Nova',

	/* Not in CLDR 27.0.1. Laki language
	 * https://www.ethnologue.com/language/lki
	 */
	'lki' => 'لکی',

	/* Not in CLDR 27.0.1. Latvian language
	 * https://iso639-3.sil.org/code/ltg
	 * Added 2010-04-03.
	 */
	'ltg' => 'لاتگالی',

	/* Not in CLDR 27.0.1. Southern Luri language
	 * https://www.ethnologue.com/language/luz
	 */
	'luz' => 'لری جنوبی',

	/* Not in CLDR 27.0.1. Mari language
	 * https://www.ethnologue.com/language/mhr
	 * Added 2008-05-22.
	 */
	'mhr' => 'ماری',

	/* Not in CLDR 27.0.1. Mari language
	 * https://www.ethnologue.com/language/mrj
	 * Added 2009-11-22.
	 */
	'mrj' => 'هیل ماری',

	/* Not in CLDR 27.0.1. Malay language
	 * https://www.ethnologue.com/language/mui
	 * Added 2010-02-11.
	 */
	// 'mui' => 'Musi',

	/* Not in CLDR 27.0.1. Chinese language
	 * https://www.ethnologue.com/language/nan
	 * Added 2008-03-01.
	 */
	'nan' => 'مین نان',

	/* Not in CLDR 27.0.1. Tibeto-Burman family language.
	 * https://www.ethnologue.com/language/njo
	 * Added 2008-01-14.
	 */
	// 'njo' => 'Ao Naga',

	/* Not in CLDR 27.0.1. Livvi-Karelian language
	 * https://www.ethnologue.com/language/olo
	 */
	'olo' => 'لیوی-کارلیان',

	/* Not in CLDR 27.0.1. Gallo-Italian language.
	 * https://www.ethnologue.com/language/pms
	 * Added 2008-07-09.
	 */
	'pms' => 'پیدمونتی',

	/* Not in CLDR 27.0.1. Lahnda language.
	 * https://www.ethnologue.com/language/pnb
	 * Added 2008-10-29.
	 */
	'pnb' => 'پنجابی',

	/* Not in CLDR 27.0.1. Attic language.
	 * https://www.ethnologue.com/language/pnt
	 * Added 2008-01-18.
	 */
	// 'pnt' => 'Pontic',

	/* Not in CLDR 27.0.1. Dari language.
	 * https://www.ethnologue.com/language/prs
	 */
	'prs' => 'دری',

	/* Not in CLDR 27.0.1. Gallo-Italic language.
	 * https://iso639-3.sil.org/code/rgn
	 * Added 2009-11-15.
	 */
	'rgn' => 'رومانیولو',

	/* Not in CLDR 27.0.1. East Slavic language.
	 * https://www.ethnologue.com/language/rue
	 * Added 2010-04-03.
	 */
	// 'rue' => 'Rusyn',

	/* Not in CLDR 27.0.1. Eastern Romance language.
	 * https://www.ethnologue.com/language/ruq
	 * Added 2008-02-04.
	 */
	'ruq' => 'مگلنو رومانی',
	'ruq-cyrl' => 'مگلنو رومانی (خط سرلیک)',
	'ruq-grek' => 'مگلنو رومانی (خط یونانی)',
	'ruq-latn' => 'مگلنو رومانی (خط لاتین)',

	/* Not in CLDR 27.0.1.
	 * https://iso639-3.sil.org/code/sgs
	 * Added 2010-10-14.
	 */
	'sgs' => 'ساموگیتی',

	/* Not in CLDR 27.0.1. Shawiya language
	 * https://www.ethnologue.com/language/shy
	 */
	'shy' => 'شاویایی',
	'shy-arab' => 'شاویایی (خط عربی)',
	'shy-latn' => 'شاویایی (خط لاتین)',
	'shy-tfng' => 'شاویایی (خط تیفیناغی)',

	/* Not in CLDR 27.0.1. Tulu language
	 * https://iso639-3.sil.org/code/tcy
	 * Added 2008-08-23.
	 */
	'tcy' => 'تولو',

	/* Not in CLDR 27.0.1. Turoyo language
	 * https://iso639-3.sil.org/code/tru
	 * Added 2012-07-26.
	 */
	// 'tru' => 'Turoyo',

	/* Not in CLDR 27.0.1. Finnic Uralic language.
	 * https://www.ethnologue.com/language/vep
	 * Added 2009-01-24.
	 */
	'vep' => 'وپس',

	/* Not in CLDR 27.0.1. West Middle German language.
	 * https://iso639-3.sil.org/code/vmf
	 * Added 2010-01-31.
	 */
	// 'vmf' => 'Upper Franconian',

	/* Not in CLDR 27.0.1. Estonian language.
	 * https://iso639-3.sil.org/code/vro
	 * Added 2009-01-24.
	 */
	// 'vro' => 'Võro',

	/* Not in CLDR 27.0.1. Chinese language.
	 * https://www.ethnologue.com/language/wuu
	 * Added 2007-12-02.
	 */
	'wuu' => 'وو',

	/* Not in CLDR 27.0.1. Low Franconian language.
	 * https://www.ethnologue.com/language/zea
	 * Added 2008-01-17.
	 */
	'zea' => 'زیلاندی',

	/* Not in CLDR 27.0.1. Used for MediaWiki localisation
	 */
	'bat-smg' => 'ساموگیتی',
	'be-tarask' => 'بلاروسی (دستورخط کلاسیک)',
	'cdo' => 'چینی مین شرقی',
	'crh-cyrl' => 'ترکی کریمه (خط سرلیک)',
	'crh-latn' => 'ترکی کریمه (خط لاتین)',
	// 'de-formal' => 'German (formal address)',
	'gan-hans' => 'خط گن ساده‌شده',
	'gan-hant' => 'خط گن سنتی',
	'hif-latn' => 'هندی فیجی (خط لاتینی)',
	'ike-cans' => 'کانادایی شرقی (هجاهای بومی)',
	'ike-latn' => 'کانادایی شرقی (خط لاتینی)',
	'kk-cn' => 'قزافی(چینی)',
	'kk-kz' => 'قزاقی (قزاقستان)',
	'kk-tr' => 'قزاقی (ترکیە)',
	'kk-arab' => 'قزاقی (خط عربی)',
	'kk-cyrl' => 'قزاقی (خط سریلیک)',
	'kk-latn' => 'قزاقی (خط لاتینی)',
	'ks-arab' => 'کشمیری (خط عربی)',
	'ks-deva' => 'کشمیری (خط دیواناگری)',
	'ku-latn' => 'کردی (خط لاتین)',
	// 'nds-nl' => 'Low Saxon (Netherlands)',
	'roa-rup' => 'آرومانی',
	'sr-ec' => 'صربی (خط سرلیک)',
	'sr-el' => 'صربی (خط لاتین)',
	'tg-cyrl' => 'تاجیکی (خط سرلیک)',
	'tg-latn' => 'تاجیکی (خط لاتین)',
	'tt-cyrl' => 'تاتاری (خط سرلیک)',
	'tt-latn' => 'تاتاری (خط لاتین)',
	'ug-arab' => 'اویغوری (خط عربی)',
	'ug-latn' => 'اویغوری (خط لاتین)',
	// 'xmf' => 'Mingrelian',
	'ydd' => 'ییدیشی شرقی',
	'zh-classical' => 'چینی کلاسیک',
	'zh-cn' => 'چینی (چین)',
	'zh-hk' => 'چینی (هنگ کنگ)',
	'zh-min-nan' => 'چینی (مین نان)',
	'zh-sg' => 'چینی (سنگاپور)',
	'zh-tw' => 'چینی (تایوان)',
	# language redirect
	'zh-yue' => 'کانتونی',

	/* additional list from Persian Wikipedia */
	'simple' => 'انگلیسی ساده',
];
